function TrialData = runFoodRatingTrial(foodnum, PTBParams)
% function TrialData = runFoodRatingTrial(foodnum, PTBParams)
%
% foodnum = specifies which food to display
% PTBParams = structure specifying various study parameters
%

%% 1. Display trial fixation
Screen('DrawDots',PTBParams.win, [0;0], 10, [255,0,0]', PTBParams.ctr, 1);
TrialStartTime = Screen(PTBParams.win, 'Flip');

%% 2. Display food and collect response

% load food picture for trial
Food = PTBParams.FoodNames{foodnum};
[FoodTexture, FoodSize] = makeTxtrFromImg(fullfile(PTBParams.foodPath,Food),'JPG', PTBParams);

% specify location of the food on the screen
picLoc = findPicLoc(FoodSize,[.5,.45],PTBParams,'ScreenPct',.4);
Screen('DrawTexture', PTBParams.win, FoodTexture,[],picLoc);

% specify location of the rating keys on the screen
picLoc = findPicLoc(PTBParams.RateKeysSize,[.5,.85],PTBParams,'ScreenPct',.4);
Screen('DrawTexture', PTBParams.win, PTBParams.RateKeys,[],picLoc);

FoodOnTime = Screen(PTBParams.win,'Flip',TrialStartTime + .25);

% collect a response (allowing for test mode)
if PTBParams.subjid > 1000
    PTBParams.testMode = true;
end

[Resp, RT] = collectResponse([],[],PTBParams.numKeys(1:6),PTBParams.KbDevice,PTBParams);
Resp = str2double(Resp(1));
RT = RT - FoodOnTime;

%% 3. Display post-choice fixation

Screen('DrawDots',PTBParams.win, [0;0], 10, [255,0,0]', PTBParams.ctr, 1);
FixationOnTime = Screen(PTBParams.win, 'Flip');

WaitSecs(.05);


%% 4. Bundle trial data into a structure for output

TrialData.Food = Food;
TrialData.Resp = Resp;
TrialData.RT = RT;
TrialData.TrialStartTime = TrialStartTime;
TrialData.FoodOnTime = FoodOnTime;

%% 5. Clean up images (avoids memory leaks)
Screen('Close',FoodTexture);

